pub struct BlockHandler {
pub chain_id: u64,
pub block_sender: Sender<ExecutionPayload>,
pub unsafe_signer_recv: Receiver<Address>,
pub blocks_v1_topic: IdentTopic,
pub blocks_v2_topic: IdentTopic,
pub blocks_v3_topic: IdentTopic,
}Expand description
Responsible for managing blocks received via p2p gossip
Fields
chain_id: u64Chain ID of the L2 blockchain. Used to filter out gossip messages intended for other blockchains.
block_sender: Sender<ExecutionPayload>A channel sender to forward new blocks to other modules
unsafe_signer_recv: Receiver<Address>A Receiver to monitor changes to the unsafe block signer.
blocks_v1_topic: IdentTopicThe libp2p topic for pre Canyon/Shangai blocks.
blocks_v2_topic: IdentTopicThe libp2p topic for Canyon/Delta blocks.
blocks_v3_topic: IdentTopicThe libp2p topic for Ecotone V3 blocks.
Implementations
Sourceimpl BlockHandler
impl BlockHandler
Sourcepub fn new(
chain_id: u64,
unsafe_recv: Receiver<Address>,
) -> (Self, Receiver<ExecutionPayload>)
pub fn new( chain_id: u64, unsafe_recv: Receiver<Address>, ) -> (Self, Receiver<ExecutionPayload>)
Creates a new BlockHandler and opens a channel
Sourcepub fn block_valid(&self, envelope: &OpNetworkPayloadEnvelope) -> bool
pub fn block_valid(&self, envelope: &OpNetworkPayloadEnvelope) -> bool
Determines if a block is valid.
True if the block is less than 1 minute old, and correctly signed by the unsafe block signer.